.g-sentry-value-container{margin:10px 0;padding:3px 9px;border:1px solid #ddd;background-color:#f6f6f6}.g-sentry-value-container .g-sentry-value{display:inline-block;margin-left:15px;font-family:monospace}
